/*
    SPDX-FileCopyrightText: 2016 Rohan Garg <rohan@kde.org>
    SPDX-FileCopyrightText: 2020 Harald Sitter <sitter@kde.org>
    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
*/

#ifndef GPUENTRY_H
#define GPUENTRY_H

#include "Entry.h"

class GPUEntry : public Entry
{
public:
    GPUEntry();
};

#endif // GPUENTRY_H
